@@ -62,7 +62,7 @@ do_map (void)
   }
 
   /* Did we get the requested map? */
-  if (!nbd_can_meta_context (nbd, map)) {
+  if (nbd_can_meta_context (nbd, map) < 1) {
     fprintf (stderr,
              "%s: --map: server does not support metadata context \"%s\"\n",
              progname, map);
@@ -95,8 +95,18 @@ do_map (void)
                progname);
       exit (EXIT_FAILURE);
     }
-    for (i = prev_entries_size; i < entries.len; i++)
+    for (i = prev_entries_size; i < entries.len; i++) {
+      /* nbdkit < 1.44 has a bug where even though we requested an
+       * aligned request at 4G-alignment, the result can be unaligned
+       * if it is larger than the request.  The easiest workaround is
+       * to ignore the slop.
+       */
+      if (entries.ptr[i].length > max_len) {
+        entries.ptr[i].length = max_len;
+        entries.len = i + 1;
+      }
       offset += entries.ptr[i].length;
+    }
   }
 
   if (!totals)
